Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Systems Manager Incident Manager Contacts.

Actions, resources, and condition keys for AWS Systems Manager Incident Manager Contacts - Service Authorization Reference

# Actions, resources, and condition keys for AWS Systems Manager Incident Manager Contacts

AWS Systems Manager Incident Manager Contacts (service prefix: `ssm-contacts` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Systems Manager Incident Manager Contacts
- Resource types defined by AWS Systems Manager Incident Manager Contacts
- Condition keys for AWS Systems Manager Incident Manager Contacts

## Actions defined by AWS Systems Manager Incident Manager Contacts

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptPage | Grants permission to accept a page | Write | page* |  |
ActivateContactChannel | Grants permission to activate a contact's contact channel | Write | contactchannel* |  |
AssociateContact [permission only] | Grants permission to use a contact in an escalation plan | Permissions management | contact* |  |
CreateContact | Grants permission to create a contact | Write | contact* |  | ssm-contacts:AssociateContact
CreateContactChannel | Grants permission to create a contact channel for a contact | Write | contact* |  |
DeactivateContactChannel | Grants permission to deactivate a contact's contact channel | Write | contactchannel* |  |
DeleteContact | Grants permission to delete a contact | Write | contact* |  |
DeleteContactChannel | Grants permission to delete a contact's contact channel | Write | contactchannel* |  |
DeleteContactPolicy | Grants permission to delete a contact's resource policy | Write | contact* |  |
DescribeEngagement | Grants permission to describe an engagement | Read | engagement* |  |
DescribePage | Grants permission to describe a page | Read | page* |  |
GetContact | Grants permission to get a contact | Read | contact* |  |
GetContactChannel | Grants permission to get a contact's contact channel | Read | contactchannel* |  |
GetContactPolicy | Grants permission to get a contact's resource policy | Read | contact* |  |
ListContactChannels | Grants permission to list all of a contact's contact channels | List | contact* |  |
ListContacts | Grants permission to list all contacts | List |  |  |
ListEngagements | Grants permission to list all engagements | List |  |  |
ListPageReceipts | Grants permission to list all receipts of a page | List | page* |  |
ListPagesByContact | Grants permission to list all pages sent to a contact | List | contact* |  |
ListPagesByEngagement | Grants permission to list all pages created in an engagement | List | engagement* |  |
ListTagsForResource | Grants permission to view a list of resource tags for a specified resource | Read | contact* |  |
PutContactPolicy | Grants permission to add a resource policy to a contact | Write | contact* |  |
SendActivationCode | Grants permission to send the activation code of a contact's contact channel | Write | contactchannel* |  |
StartEngagement | Grants permission to start an engagement | Write | contact* |  |
StopEngagement | Grants permission to stop an engagement | Write | engagement* |  |
TagResource | Grants permission to add tags to a response plan | Tagging | contact* |  |
UntagResource | Grants permission to remove tags from a response plan | Tagging | contact* |  |
UpdateContact | Grants permission to update a contact | Write | contact* |  | ssm-contacts:AssociateContact
UpdateContactChannel | Grants permission to update a contact's contact channel | Write | contactchannel* |  |
UpdateContactPolicy | Grants permission to update a contact's resource policy | Write | contact* |  |

## Resource types defined by AWS Systems Manager Incident Manager Contacts

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
contact | `arn:$ { Partition}:ssm-contacts:$ { Region}:$ { Account}:contact/$ { ContactAlias}` |
contactchannel | `arn:$ { Partition}:ssm-contacts:$ { Region}:$ { Account}:contactchannel/$ { ContactAlias}/$ { ContactChannelId}` |
engagement | `arn:$ { Partition}:ssm-contacts:$ { Region}:$ { Account}:engagement/$ { ContactAlias}/$ { EngagementId}` |
page | `arn:$ { Partition}:ssm-contacts:$ { Region}:$ { Account}:page/$ { ContactAlias}/$ { PageId}` |

## Condition keys for AWS Systems Manager Incident Manager Contacts

Incident Manager Contacts has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.